/****************************************************************/
/*	Sample code for  SM28VLT32-HT flash API
	Platform:	IAR Workbench, MSWindows
	Target  :	SM470R1B1M-HT	
    
	Developed by		   : Varalakshmi B
	Developed on		   : 13th Dec 2012
	Release Ver		   : 1.0		        */
/****************************************************************/

#include <intrinsics.h>
#include <TexasInstruments/iotms470r1b1m.h>
#include <TexasInstruments/tms470r1B1m_bit_definitions.h>

#include "SM28VLT32.h"

// Function to test a sector in flash
int Flash_TestSector(int iSectorToTest);


/**************************************************************/
/********************** Main Function *************************/
/**************************************************************/
void main(void)
{   
    int iSectorToTest = 30;
    int iRetValue = 0;
    
    // Setup SPI for flash
    Flash_Init(); 
    
    // Test Sector -  Returns 0 on sucess, Returns -1 on failure
    iRetValue = Flash_TestSector(iSectorToTest); 
}



// Function to test a sector in flash
int Flash_TestSector(int iSectorToTest)
{
    int iCnt, ErrorCode;
    unsigned short data;
    int StartAddress = iSectorToTest * FLASH_SECTOR_SIZE;
    int EndAddress = StartAddress + FLASH_SECTOR_SIZE;

    // Erase Sector -  Any address between Start Address and End address can be given as input
    ErrorCode = Flash_EraseSector(StartAddress); 
    if((ErrorCode & FLASH_QS_COMMAND_ERROR) || 
                (ErrorCode & FLASH_QS_INVALID_DATA_ERROR))
    {
        // Clear error bits
        Flash_ClearError(); 
        return -1;
    }
    
    for(iCnt=StartAddress; iCnt<EndAddress; iCnt++)
    {
        // Write to each flash address in sector
        ErrorCode = Flash_Write(iCnt, (iCnt & 0xFFFF));
        if((ErrorCode & FLASH_QS_COMMAND_ERROR) || 
                (ErrorCode & FLASH_QS_INVALID_DATA_ERROR))
        {
            // Clear error bits
            Flash_ClearError(); 
            return -1;
        }
        else
        {	// Read each flash address in sector and compare
            ErrorCode = Flash_Read(iCnt, &data);
            if(data != (iCnt & 0xFFFF))
            {
                    return -1;
            }
        }
    }       
   
    return 0;  
}
